CalendarStorePruneDeleted

Trait CalendarStorePruneDeleted 

pub trait CalendarStorePruneDeleted:
    Send
    + Sync
    + 'static {
    // Required methods
    fn prune_deleted_calendars<'life0, 'async_trait>(
        &'life0 self,
        before: NaiveDate,
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn prune_deleted_objects<'life0, 'async_trait>(
        &'life0 self,
        before: NaiveDate,
    ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}

Required Methods

fn prune_deleted_calendars<'life0, 'async_trait>( &'life0 self, before: NaiveDate, ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Removes all calendars marked for deletion before specified date

fn prune_deleted_objects<'life0, 'async_trait>( &'life0 self, before: NaiveDate, ) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Removes all objects marked for deletion before specified date

Implementors